<?php
/*
Plugin Name: Heads Up Robot
Description: Adds a footer message to your site with customizable settings.
Version: 1.0
Author: Your Name
*/

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}


// Register the settings.
add_action( 'admin_init', 'hur_register_settings' );
function hur_register_settings() {
    register_setting( 'hur-settings-group', 'hur_enable' );
    register_setting( 'hur-settings-group', 'hur_color' );
    register_setting( 'hur-settings-group', 'hur_bg' );
    register_setting( 'hur-settings-group', 'hur_font_size' );
    register_setting( 'hur-settings-group', 'hur_alignment' );
}

// Add settings menu item.
add_action( 'admin_menu', 'hur_add_menu_item' );
function hur_add_menu_item() {
    add_options_page( 'Heads Up Robot Settings', 'Heads Up Robot', 'manage_options', 'heads-up-robot', 'hur_settings_page' );
}

add_action( 'admin_enqueue_scripts', 'mw_enqueue_color_picker' );
function mw_enqueue_color_picker( $hook_suffix ) {
    // first check that $hook_suffix is appropriate for your admin page
    wp_enqueue_style( 'wp-color-picker' );
    wp_enqueue_script( 'my-script-handle', plugins_url('hur-script.js', __FILE__ ), array( 'wp-color-picker' ), false, true );
}


//settings link

add_filter( 'plugin_action_links', 'hur_settings_plugin_link', 10, 2 );

function hur_settings_plugin_link( $links, $file ) 
{
    if ( $file == plugin_basename(dirname(__FILE__) . '/heads-up-robot.php') ) 
    {
        
        $in = '<a href="options-general.php?page=heads-up-robot">' . __('Settings','mtt') . '</a>';
        array_unshift($links, $in);

        
    }
    return $links;
}



// Display the settings page.
function hur_settings_page() {
    ?>
    <div class="wrap">
        <h1>Heads Up Robot Settings</h1>

  
      
        

        
            <form method="post" action="options.php">
                <?php settings_fields( 'hur-settings-group' ); ?>
                <?php do_settings_sections( 'hur-settings-group' ); ?>
                <table class="form-table">
                    <tr valign="top">
                        <th scope="row">Enable Footer Link</th>
                        <td><input type="checkbox" name="hur_enable" value="1" <?php checked( 1, get_option( 'hur_enable', 0 ) ); ?> /></td>
                    </tr>
                    <tr valign="top">
                        <th scope="row">Text Color</th>
                        <td><input class = "hur-color-field" type="text" name="hur_color" value="<?php echo esc_attr( get_option( 'hur_color', '#000000' ) ); ?>" data-default-color="<?php echo esc_attr( get_option( 'hur_color', '#000000' ) ); ?>" /></td>
                    </tr>
                    <tr valign="top">
                        <th scope="row">Background Color</th>
                        <td><input class = "hur-color-field" type="text" name="hur_bg" value="<?php echo esc_attr( get_option( 'hur_bg', '#000000' ) ); ?>" data-default-color="<?php echo esc_attr( get_option( 'hur_bg', '#000000' ) ); ?>" /></td>
                    </tr>
                    <tr valign="top">
                        <th scope="row">Font Size (px)</th>
                        <td><input type="number" name="hur_font_size" value="<?php echo esc_attr( get_option( 'hur_font_size', '14' ) ); ?>" /></td>
                    </tr>
                    <tr valign="top">
                        <th scope="row">Alignment</th>
                        <td>
                            <select name="hur_alignment">
                                <option value="left" <?php selected( get_option( 'hur_alignment', 'left' ), 'left' ); ?>>Left</option>
                                <option value="center" <?php selected( get_option( 'hur_alignment', 'center' ), 'center' ); ?>>Center</option>
                                <option value="right" <?php selected( get_option( 'hur_alignment', 'right' ), 'right' ); ?>>Right</option>
                            </select>
                        </td>
                    </tr>
                </table>
                <?php submit_button(); ?>
            </form>
       
        <h1>Why use Heads Up Robot?</h1>
        <p>You can build the best site with awesome onsite SEO and strong backlinks but if your site is not up, your visitors will be denied your amazing content. If you are running an ecommerce store the cash register will stop ringing. If that is not enough of a penalty, Google will also move you down the SERP rankings reducing your visitors in the future.</p>
        <P>Heads Up Robot will help keep you in the loop so you can fix the issues quickly and prevent this all from happening.</P>

        <p>Be sure your hosting provide is providing uptime within its service level agreement(SLA)</p>
        <p>Site being brought down due to denial of service attacks, you'll hear about it</p>
        <p>Perhaps your site has been taken over by malware and redirecting to a hackers website, you'll be notified.</p>
        <p>Is your database full and falling over, get an email telling you the moment the database goes down.</p>
        <p>Have you or your hosting provider forgotten to renew your SSL certificate or has it expired. Heads Up Robot will be your guardian angel and let you know.</p>

        
        <h1>Instructions</h1>
        
        <p>In order for Heads Up Robot to monitor your site it needs a word, it knows, will always be on the homepage.</p>
         <p>By checking the box in the settings a link will be added to the bottom of your homepage. This is what the Heads Up Robot will be looking for when it checks your site</p>
        <p> The link can be customizable by using the settings</p>
        <p>Then sign up for a free account at <strong><a href ="https://headsuprobot.com">headsuprobot.com</a></strong> and add this websites url <?php echo esc_html(get_home_url()); ?> to monitor it.</p>
        <p>You are all set. Every hour Heads Up Robot will test if your site is up, your site SSL certificate is valid and any DNS record changes. </p>
        <p>If Heads Up Robot finds an issue it will send you an email and will follow up with a subsequent email when the issue is resolved.</p>

        <h1>How much is Heads Up Robot</h1>
        <p>We offer it for FREE to individual websites. </p>
            <p>More than one website or an agency we have a paid plan for you that won't break the bank.</p>


        <h1>Want more?</h1>
        <p>If you would like to increase the monitoring frequency you can upgrade your account to a Pro account. This will increase the frequencies to every minute, allow you to be notified, by text, the moment Heads Up Robot finds an issue. You can also remove the footer link and set yor own text for Heads Up Robot to find.</p>
        
    </div>

    <?php
}

// Display the footer message.
add_action( 'wp_footer', 'hur_display_footer_message' );
function hur_display_footer_message() {
    if (( get_option( 'hur_enable', 0 )) && (( is_home() || is_front_page()))) {
        $color = esc_attr( get_option( 'hur_color', '#000000' ) );
        $bgcolor = esc_attr( get_option( 'hur_bg', '#ffffff' ) );
        $font_size = esc_attr( get_option( 'hur_font_size', '14' ) );
        $alignment = esc_attr( get_option( 'hur_alignment', 'center' ) );
        echo '<div style="background-color:' . esc_html($bgcolor) . '; color:' . esc_html($color) . '; font-size:' . esc_html($font_size) . 'px; text-align:' . esc_html($alignment) . ';">Site Monitored by <a style="color:' . esc_html($color) . '; font-size:' . esc_html($font_size) . 'px;" href="https://headsuprobot.com">Heads Up Robot</a></div>';
    }
}
?>
